# A Python wrapper for ABB's Robot Web Services 

A small wrapper I needed as part of my master's thesis

## About The Project

Class for communicating with RobotWare through Robot Web Services (ABB's Rest API)

### NB!
This package will most likely not be regularly maintained, and should be used as is, or as a RWS usage guide.

## Contact
Project Link: [https://github.com/andreasstrom/RWS-wrapper](https://github.com/andreasstrom/RWS-wrapper)

## License

Distributed under the MIT License.

## Acknowledgments

This class was built on the foundation of the work done in https://github.com/prinsWindy/ABB-Robot-Machine-Vision, and have been modified and expanded on as a tool in my master's thesis work.
"For the RW 7.0 release, RWS has introduced several breaking changes to include the following requirements" -> Updates needed

<p align="right">(<a href="#top">back to top</a>)</p>